# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKRegistrationCommonPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkMutualInformationImageToImageMetricPython
else:
    import _itkMutualInformationImageToImageMetricPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkArrayPython
import itk.itkImageToImageMetricPython
import itk.itkImagePython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkSpatialObjectBasePython
import itk.itkBoundingBoxPython
import itk.itkMapContainerPython
import itk.itkVectorContainerPython
import itk.itkContinuousIndexPython
import itk.itkSpatialObjectPropertyPython
import itk.itkAffineTransformPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkVariableLengthVectorPython
import itk.itkOptimizerParametersPython
import itk.itkArray2DPython
import itk.itkTransformBasePython
import itk.itkDiffusionTensor3DPython
import itk.itkInterpolateImageFunctionPython
import itk.itkImageFunctionBasePython
import itk.itkFunctionBasePython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.ITKCostFunctionsPython
import itk.vnl_cost_functionPython
import itk.vnl_unary_functionPython
import itk.vnl_least_squares_functionPython
import itk.itkCostFunctionPython

def itkMutualInformationImageToImageMetricIF2IF2_New():
    return itkMutualInformationImageToImageMetricIF2IF2.New()

class itkMutualInformationImageToImageMetricIF2IF2(itk.itkImageToImageMetricPython.itkImageToImageMetricIF2IF2):
    r"""Proxy of C++ itkMutualInformationImageToImageMetricIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMutualInformationImageToImageMetricIF2IF2_Pointer"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMutualInformationImageToImageMetricIF2IF2_Pointer"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF2IF2_Clone(self)

    def SetNumberOfSpatialSamples(self, num):
        r"""
        SetNumberOfSpatialSamples(self, num)

        Parameters
        ----------
        num: unsigned int

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF2IF2_SetNumberOfSpatialSamples(self, num)

    def GetNumberOfSpatialSamples(self):
        r"""GetNumberOfSpatialSamples(self) -> unsigned int const &"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF2IF2_GetNumberOfSpatialSamples(self)

    def SetMovingImageStandardDeviation(self, _arg):
        r"""
        SetMovingImageStandardDeviation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF2IF2_SetMovingImageStandardDeviation(self, _arg)

    def GetMovingImageStandardDeviation(self):
        r"""GetMovingImageStandardDeviation(self) -> double const &"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF2IF2_GetMovingImageStandardDeviation(self)

    def SetFixedImageStandardDeviation(self, _arg):
        r"""
        SetFixedImageStandardDeviation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF2IF2_SetFixedImageStandardDeviation(self, _arg)

    def GetFixedImageStandardDeviation(self):
        r"""GetFixedImageStandardDeviation(self) -> double"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF2IF2_GetFixedImageStandardDeviation(self)

    def SetKernelFunction(self, _arg):
        r"""
        SetKernelFunction(self, _arg)

        Parameters
        ----------
        _arg: itk::KernelFunctionBase< > *

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF2IF2_SetKernelFunction(self, _arg)

    def GetModifiableKernelFunction(self):
        r"""GetModifiableKernelFunction(self) -> itk::KernelFunctionBase< > *"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF2IF2_GetModifiableKernelFunction(self)

    def GetKernelFunction(self, *args):
        r"""
        GetKernelFunction(self) -> itk::KernelFunctionBase< > const
        GetKernelFunction(self) -> itk::KernelFunctionBase< > *
        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF2IF2_GetKernelFunction(self, *args)
    __swig_destroy__ = _itkMutualInformationImageToImageMetricPython.delete_itkMutualInformationImageToImageMetricIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMutualInformationImageToImageMetricIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMutualInformationImageToImageMetricIF2IF2

        Create a new object of the class itkMutualInformationImageToImageMetricIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMutualInformationImageToImageMetricIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMutualInformationImageToImageMetricIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMutualInformationImageToImageMetricIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMutualInformationImageToImageMetricIF2IF2 in _itkMutualInformationImageToImageMetricPython:
_itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF2IF2_swigregister(itkMutualInformationImageToImageMetricIF2IF2)

def itkMutualInformationImageToImageMetricIF3IF3_New():
    return itkMutualInformationImageToImageMetricIF3IF3.New()

class itkMutualInformationImageToImageMetricIF3IF3(itk.itkImageToImageMetricPython.itkImageToImageMetricIF3IF3):
    r"""Proxy of C++ itkMutualInformationImageToImageMetricIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMutualInformationImageToImageMetricIF3IF3_Pointer"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMutualInformationImageToImageMetricIF3IF3_Pointer"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF3IF3_Clone(self)

    def SetNumberOfSpatialSamples(self, num):
        r"""
        SetNumberOfSpatialSamples(self, num)

        Parameters
        ----------
        num: unsigned int

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF3IF3_SetNumberOfSpatialSamples(self, num)

    def GetNumberOfSpatialSamples(self):
        r"""GetNumberOfSpatialSamples(self) -> unsigned int const &"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF3IF3_GetNumberOfSpatialSamples(self)

    def SetMovingImageStandardDeviation(self, _arg):
        r"""
        SetMovingImageStandardDeviation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF3IF3_SetMovingImageStandardDeviation(self, _arg)

    def GetMovingImageStandardDeviation(self):
        r"""GetMovingImageStandardDeviation(self) -> double const &"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF3IF3_GetMovingImageStandardDeviation(self)

    def SetFixedImageStandardDeviation(self, _arg):
        r"""
        SetFixedImageStandardDeviation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF3IF3_SetFixedImageStandardDeviation(self, _arg)

    def GetFixedImageStandardDeviation(self):
        r"""GetFixedImageStandardDeviation(self) -> double"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF3IF3_GetFixedImageStandardDeviation(self)

    def SetKernelFunction(self, _arg):
        r"""
        SetKernelFunction(self, _arg)

        Parameters
        ----------
        _arg: itk::KernelFunctionBase< > *

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF3IF3_SetKernelFunction(self, _arg)

    def GetModifiableKernelFunction(self):
        r"""GetModifiableKernelFunction(self) -> itk::KernelFunctionBase< > *"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF3IF3_GetModifiableKernelFunction(self)

    def GetKernelFunction(self, *args):
        r"""
        GetKernelFunction(self) -> itk::KernelFunctionBase< > const
        GetKernelFunction(self) -> itk::KernelFunctionBase< > *
        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF3IF3_GetKernelFunction(self, *args)
    __swig_destroy__ = _itkMutualInformationImageToImageMetricPython.delete_itkMutualInformationImageToImageMetricIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMutualInformationImageToImageMetricIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMutualInformationImageToImageMetricIF3IF3

        Create a new object of the class itkMutualInformationImageToImageMetricIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMutualInformationImageToImageMetricIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMutualInformationImageToImageMetricIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMutualInformationImageToImageMetricIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMutualInformationImageToImageMetricIF3IF3 in _itkMutualInformationImageToImageMetricPython:
_itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIF3IF3_swigregister(itkMutualInformationImageToImageMetricIF3IF3)

def itkMutualInformationImageToImageMetricISS2ISS2_New():
    return itkMutualInformationImageToImageMetricISS2ISS2.New()

class itkMutualInformationImageToImageMetricISS2ISS2(itk.itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2):
    r"""Proxy of C++ itkMutualInformationImageToImageMetricISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMutualInformationImageToImageMetricISS2ISS2_Pointer"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMutualInformationImageToImageMetricISS2ISS2_Pointer"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS2ISS2_Clone(self)

    def SetNumberOfSpatialSamples(self, num):
        r"""
        SetNumberOfSpatialSamples(self, num)

        Parameters
        ----------
        num: unsigned int

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS2ISS2_SetNumberOfSpatialSamples(self, num)

    def GetNumberOfSpatialSamples(self):
        r"""GetNumberOfSpatialSamples(self) -> unsigned int const &"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS2ISS2_GetNumberOfSpatialSamples(self)

    def SetMovingImageStandardDeviation(self, _arg):
        r"""
        SetMovingImageStandardDeviation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS2ISS2_SetMovingImageStandardDeviation(self, _arg)

    def GetMovingImageStandardDeviation(self):
        r"""GetMovingImageStandardDeviation(self) -> double const &"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS2ISS2_GetMovingImageStandardDeviation(self)

    def SetFixedImageStandardDeviation(self, _arg):
        r"""
        SetFixedImageStandardDeviation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS2ISS2_SetFixedImageStandardDeviation(self, _arg)

    def GetFixedImageStandardDeviation(self):
        r"""GetFixedImageStandardDeviation(self) -> double"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS2ISS2_GetFixedImageStandardDeviation(self)

    def SetKernelFunction(self, _arg):
        r"""
        SetKernelFunction(self, _arg)

        Parameters
        ----------
        _arg: itk::KernelFunctionBase< > *

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS2ISS2_SetKernelFunction(self, _arg)

    def GetModifiableKernelFunction(self):
        r"""GetModifiableKernelFunction(self) -> itk::KernelFunctionBase< > *"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS2ISS2_GetModifiableKernelFunction(self)

    def GetKernelFunction(self, *args):
        r"""
        GetKernelFunction(self) -> itk::KernelFunctionBase< > const
        GetKernelFunction(self) -> itk::KernelFunctionBase< > *
        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS2ISS2_GetKernelFunction(self, *args)
    __swig_destroy__ = _itkMutualInformationImageToImageMetricPython.delete_itkMutualInformationImageToImageMetricISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMutualInformationImageToImageMetricISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMutualInformationImageToImageMetricISS2ISS2

        Create a new object of the class itkMutualInformationImageToImageMetricISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMutualInformationImageToImageMetricISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMutualInformationImageToImageMetricISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMutualInformationImageToImageMetricISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMutualInformationImageToImageMetricISS2ISS2 in _itkMutualInformationImageToImageMetricPython:
_itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS2ISS2_swigregister(itkMutualInformationImageToImageMetricISS2ISS2)

def itkMutualInformationImageToImageMetricISS3ISS3_New():
    return itkMutualInformationImageToImageMetricISS3ISS3.New()

class itkMutualInformationImageToImageMetricISS3ISS3(itk.itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3):
    r"""Proxy of C++ itkMutualInformationImageToImageMetricISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMutualInformationImageToImageMetricISS3ISS3_Pointer"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMutualInformationImageToImageMetricISS3ISS3_Pointer"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS3ISS3_Clone(self)

    def SetNumberOfSpatialSamples(self, num):
        r"""
        SetNumberOfSpatialSamples(self, num)

        Parameters
        ----------
        num: unsigned int

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS3ISS3_SetNumberOfSpatialSamples(self, num)

    def GetNumberOfSpatialSamples(self):
        r"""GetNumberOfSpatialSamples(self) -> unsigned int const &"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS3ISS3_GetNumberOfSpatialSamples(self)

    def SetMovingImageStandardDeviation(self, _arg):
        r"""
        SetMovingImageStandardDeviation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS3ISS3_SetMovingImageStandardDeviation(self, _arg)

    def GetMovingImageStandardDeviation(self):
        r"""GetMovingImageStandardDeviation(self) -> double const &"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS3ISS3_GetMovingImageStandardDeviation(self)

    def SetFixedImageStandardDeviation(self, _arg):
        r"""
        SetFixedImageStandardDeviation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS3ISS3_SetFixedImageStandardDeviation(self, _arg)

    def GetFixedImageStandardDeviation(self):
        r"""GetFixedImageStandardDeviation(self) -> double"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS3ISS3_GetFixedImageStandardDeviation(self)

    def SetKernelFunction(self, _arg):
        r"""
        SetKernelFunction(self, _arg)

        Parameters
        ----------
        _arg: itk::KernelFunctionBase< > *

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS3ISS3_SetKernelFunction(self, _arg)

    def GetModifiableKernelFunction(self):
        r"""GetModifiableKernelFunction(self) -> itk::KernelFunctionBase< > *"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS3ISS3_GetModifiableKernelFunction(self)

    def GetKernelFunction(self, *args):
        r"""
        GetKernelFunction(self) -> itk::KernelFunctionBase< > const
        GetKernelFunction(self) -> itk::KernelFunctionBase< > *
        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS3ISS3_GetKernelFunction(self, *args)
    __swig_destroy__ = _itkMutualInformationImageToImageMetricPython.delete_itkMutualInformationImageToImageMetricISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMutualInformationImageToImageMetricISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMutualInformationImageToImageMetricISS3ISS3

        Create a new object of the class itkMutualInformationImageToImageMetricISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMutualInformationImageToImageMetricISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMutualInformationImageToImageMetricISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMutualInformationImageToImageMetricISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMutualInformationImageToImageMetricISS3ISS3 in _itkMutualInformationImageToImageMetricPython:
_itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricISS3ISS3_swigregister(itkMutualInformationImageToImageMetricISS3ISS3)

def itkMutualInformationImageToImageMetricIUC2IUC2_New():
    return itkMutualInformationImageToImageMetricIUC2IUC2.New()

class itkMutualInformationImageToImageMetricIUC2IUC2(itk.itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2):
    r"""Proxy of C++ itkMutualInformationImageToImageMetricIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMutualInformationImageToImageMetricIUC2IUC2_Pointer"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMutualInformationImageToImageMetricIUC2IUC2_Pointer"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC2IUC2_Clone(self)

    def SetNumberOfSpatialSamples(self, num):
        r"""
        SetNumberOfSpatialSamples(self, num)

        Parameters
        ----------
        num: unsigned int

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC2IUC2_SetNumberOfSpatialSamples(self, num)

    def GetNumberOfSpatialSamples(self):
        r"""GetNumberOfSpatialSamples(self) -> unsigned int const &"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC2IUC2_GetNumberOfSpatialSamples(self)

    def SetMovingImageStandardDeviation(self, _arg):
        r"""
        SetMovingImageStandardDeviation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC2IUC2_SetMovingImageStandardDeviation(self, _arg)

    def GetMovingImageStandardDeviation(self):
        r"""GetMovingImageStandardDeviation(self) -> double const &"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC2IUC2_GetMovingImageStandardDeviation(self)

    def SetFixedImageStandardDeviation(self, _arg):
        r"""
        SetFixedImageStandardDeviation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC2IUC2_SetFixedImageStandardDeviation(self, _arg)

    def GetFixedImageStandardDeviation(self):
        r"""GetFixedImageStandardDeviation(self) -> double"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC2IUC2_GetFixedImageStandardDeviation(self)

    def SetKernelFunction(self, _arg):
        r"""
        SetKernelFunction(self, _arg)

        Parameters
        ----------
        _arg: itk::KernelFunctionBase< > *

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC2IUC2_SetKernelFunction(self, _arg)

    def GetModifiableKernelFunction(self):
        r"""GetModifiableKernelFunction(self) -> itk::KernelFunctionBase< > *"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC2IUC2_GetModifiableKernelFunction(self)

    def GetKernelFunction(self, *args):
        r"""
        GetKernelFunction(self) -> itk::KernelFunctionBase< > const
        GetKernelFunction(self) -> itk::KernelFunctionBase< > *
        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC2IUC2_GetKernelFunction(self, *args)
    __swig_destroy__ = _itkMutualInformationImageToImageMetricPython.delete_itkMutualInformationImageToImageMetricIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMutualInformationImageToImageMetricIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMutualInformationImageToImageMetricIUC2IUC2

        Create a new object of the class itkMutualInformationImageToImageMetricIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMutualInformationImageToImageMetricIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMutualInformationImageToImageMetricIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMutualInformationImageToImageMetricIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMutualInformationImageToImageMetricIUC2IUC2 in _itkMutualInformationImageToImageMetricPython:
_itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC2IUC2_swigregister(itkMutualInformationImageToImageMetricIUC2IUC2)

def itkMutualInformationImageToImageMetricIUC3IUC3_New():
    return itkMutualInformationImageToImageMetricIUC3IUC3.New()

class itkMutualInformationImageToImageMetricIUC3IUC3(itk.itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3):
    r"""Proxy of C++ itkMutualInformationImageToImageMetricIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMutualInformationImageToImageMetricIUC3IUC3_Pointer"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMutualInformationImageToImageMetricIUC3IUC3_Pointer"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC3IUC3_Clone(self)

    def SetNumberOfSpatialSamples(self, num):
        r"""
        SetNumberOfSpatialSamples(self, num)

        Parameters
        ----------
        num: unsigned int

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC3IUC3_SetNumberOfSpatialSamples(self, num)

    def GetNumberOfSpatialSamples(self):
        r"""GetNumberOfSpatialSamples(self) -> unsigned int const &"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC3IUC3_GetNumberOfSpatialSamples(self)

    def SetMovingImageStandardDeviation(self, _arg):
        r"""
        SetMovingImageStandardDeviation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC3IUC3_SetMovingImageStandardDeviation(self, _arg)

    def GetMovingImageStandardDeviation(self):
        r"""GetMovingImageStandardDeviation(self) -> double const &"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC3IUC3_GetMovingImageStandardDeviation(self)

    def SetFixedImageStandardDeviation(self, _arg):
        r"""
        SetFixedImageStandardDeviation(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC3IUC3_SetFixedImageStandardDeviation(self, _arg)

    def GetFixedImageStandardDeviation(self):
        r"""GetFixedImageStandardDeviation(self) -> double"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC3IUC3_GetFixedImageStandardDeviation(self)

    def SetKernelFunction(self, _arg):
        r"""
        SetKernelFunction(self, _arg)

        Parameters
        ----------
        _arg: itk::KernelFunctionBase< > *

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC3IUC3_SetKernelFunction(self, _arg)

    def GetModifiableKernelFunction(self):
        r"""GetModifiableKernelFunction(self) -> itk::KernelFunctionBase< > *"""
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC3IUC3_GetModifiableKernelFunction(self)

    def GetKernelFunction(self, *args):
        r"""
        GetKernelFunction(self) -> itk::KernelFunctionBase< > const
        GetKernelFunction(self) -> itk::KernelFunctionBase< > *
        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC3IUC3_GetKernelFunction(self, *args)
    __swig_destroy__ = _itkMutualInformationImageToImageMetricPython.delete_itkMutualInformationImageToImageMetricIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMutualInformationImageToImageMetricIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMutualInformationImageToImageMetricIUC3IUC3

        Create a new object of the class itkMutualInformationImageToImageMetricIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMutualInformationImageToImageMetricIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMutualInformationImageToImageMetricIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMutualInformationImageToImageMetricIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMutualInformationImageToImageMetricIUC3IUC3 in _itkMutualInformationImageToImageMetricPython:
_itkMutualInformationImageToImageMetricPython.itkMutualInformationImageToImageMetricIUC3IUC3_swigregister(itkMutualInformationImageToImageMetricIUC3IUC3)

